pub(crate) async fn get_provider_with_wallet<N: Network + RecommendedFillers>(
tx_opts: &SendTxOpts,
) -> Result<RetryProviderWithSigner<N>>Expand description
Creates a provider with wallet for signing transactions locally.
pub(crate) async fn get_provider_with_wallet<N: Network + RecommendedFillers>(
tx_opts: &SendTxOpts,
) -> Result<RetryProviderWithSigner<N>>Creates a provider with wallet for signing transactions locally.